@@ -100,7 +100,10 @@ def parse(page,domain=''):
         pass
     names = []
     if result['title'] and namepattern:
-      names = re.findall(namepattern, result['title'], re.I)
+      try:
+        names = re.findall(namepattern, result['title'], re.I)
+      except:
+        pass
     elif result['aboutLink']  and namepattern:
       try:
         aboutres = requests.get(result['aboutLink'], timeout=15, headers=headers)
@@ -124,6 +127,6 @@ def parse(page,domain=''):
 
 
 if __name__ == '__main__':
-  res = requests.get('http://www.rel8ed.to', timeout=20, headers=headers)
-  result = parse(res.content,domain='rel8ed.to')
+  res = requests.get('http://keywebpmt.com', timeout=20, headers=headers)
+  result = parse(res.content)
   print(result)
\ No newline at end of file
